@@ -2,7 +2,7 @@
 
 import inspect
 
-from comm_utils import generate_req
+from rfsdk.comm_utils import generate_req
 
 from ant_rpc import encrypt_special
 
